svn_auth_get_gpg_agent_simple_provider

Function svn_auth_get_gpg_agent_simple_provider 

pub unsafe extern "C" fn svn_auth_get_gpg_agent_simple_provider(
    provider: *mut *mut svn_auth_provider_object_t,
    pool: *mut apr_pool_t,
)
Set @a *provider to an authentication provider of type @c svn_auth_cred_simple_t that gets/sets information from the user’s ~/.subversion configuration directory.

This is like svn_client_get_simple_provider(), except that the password is obtained from gpg_agent, which will keep it in a memory cache.

Allocate @a *provider in @a pool.

@since New in 1.8 @note This function actually works only on systems with GNU Privacy Guard installed. @deprecated Provided for backwards compatibility with the 1.8 API. Use svn_auth_get_platform_specific_provider with provider_name of “gpg_agent” and provider_type of “simple”.