pub unsafe extern "C" fn svn_base64_decode(
output: *mut svn_stream_t,
pool: *mut apr_pool_t,
) -> *mut svn_stream_tExpand description
Return a writable generic stream which will decode base64-encoded data and write the decoded data to @a output. The stream is allocated in @a pool.