pub unsafe extern "C" fn svn_cache_config_get() -> *const svn_cache_config_tExpand description
Get the current cache configuration. If it has not been set, this function will return the default settings.
@since New in 1.7.
pub unsafe extern "C" fn svn_cache_config_get() -> *const svn_cache_config_tGet the current cache configuration. If it has not been set, this function will return the default settings.
@since New in 1.7.