pub unsafe extern "C" fn svn_cache_config_set(
settings: *const svn_cache_config_t,
)Expand description
Set the cache configuration. Please note that it may not change the actual configuration in use. Therefore, call it before reading data from any repo and call it only once.
This function is not thread-safe. Therefore, it should be called from the processes’ initialization code only.
@since New in 1.7.