svn_categorize_props

Function svn_categorize_props 

pub unsafe extern "C" fn svn_categorize_props(
    proplist: *const apr_array_header_t,
    entry_props: *mut *mut apr_array_header_t,
    wc_props: *mut *mut apr_array_header_t,
    regular_props: *mut *mut apr_array_header_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Given a @a proplist array of @c svn_prop_t structures, allocate three new arrays in @a pool. Categorize each property and then create new @c svn_prop_t structures in the proper lists. Each new @c svn_prop_t structure’s fields will point to the same data within @a proplist’s structures.

Callers may pass NULL for each of the property lists in which they are uninterested. If no props exist in a certain category, and the property list argument for that category is non-NULL, then that array will come back with ->nelts == 0.