svn_checksum_match

Function svn_checksum_match 

pub unsafe extern "C" fn svn_checksum_match(
    checksum1: *const svn_checksum_t,
    checksum2: *const svn_checksum_t,
) -> svn_boolean_t
Compare checksums @a checksum1 and @a checksum2. If their kinds do not match or if neither is all zeros, and their content does not match, then return FALSE; else return TRUE.

@since New in 1.6.