pub unsafe extern "C" fn svn_checksum_mismatch_err(
expected: *const svn_checksum_t,
actual: *const svn_checksum_t,
scratch_pool: *mut apr_pool_t,
fmt: *const c_char,
...
) -> *mut svn_error_tExpand description
Return an error of type #SVN_ERR_CHECKSUM_MISMATCH for @a actual and @a expected checksums which do not match. Use @a fmt, and the following parameters to populate the error message.
@note This function does not actually check for the mismatch, it just constructs the error.
@a scratch_pool is used for temporary allocations; the returned error will be allocated in its own pool (as is typical).
@since New in 1.7.