svn_client_cat3

Function svn_client_cat3 

pub unsafe extern "C" fn svn_client_cat3(
    props: *mut *mut apr_hash_t,
    out: *mut svn_stream_t,
    path_or_url: *const c_char,
    peg_revision: *const svn_opt_revision_t,
    revision: *const svn_opt_revision_t,
    expand_keywords: svn_boolean_t,
    ctx: *mut svn_client_ctx_t,
    result_pool: *mut apr_pool_t,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Output the content of a file.

@param[out] props Optional output argument to obtain properties. @param[in] out The stream to which the content will be written. @param[in] path_or_url The path or URL of the file. @param[in] peg_revision The peg revision. @param[in] revision The operative revision. @param[in] expand_keywords When true, keywords (when set) are expanded. @param[in] ctx The standard client context, used for possible authentication.

@return A pointer to an #svn_error_t of the type (this list is not exhaustive):
An unspecified error if @a revision is of kind #svn_opt_revision_previous (or some other kind that requires a local path), because the desired revision cannot be determined.
If no error occurred, return #SVN_NO_ERROR.

If @a *props is not NULL it is set to a hash of all the file’s non-inherited properties. If it is NULL, the properties are only used for determining how and if the file should be translated.

@see #svn_client_ctx_t
@ref clnt_revisions for a discussion of operative and peg revisions.

@since New in 1.9.