pub unsafe extern "C" fn svn_client_conflict_tree_get_description(
incoming_change_description: *mut *const c_char,
local_change_description: *mut *const c_char,
conflict: *mut svn_client_conflict_t,
ctx: *mut svn_client_ctx_t,
result_pool: *mut apr_pool_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Return a textual human-readable description of the tree conflict described by @a conflict, allocated in @a result_pool. The description is encoded in UTF-8 and may contain multiple lines separated by @c APR_EOL_STR. The last line is not terminated by a newline.
Additionally, the description may be localized to the language used by the current locale.
While client implementors are free to enhance descriptions by adding additional information to the text, or break up very long lines for formatting purposes, there is no syntax defined for descriptions, and implementors should not rely on any particular parts of descriptions to remain stable over time, apart from what is stated below. Descriptions may or may not form complete sentences. They may contain paths relative to the repository root; such paths always start with “^/”, and end with either a peg revision (e.g. “@100”) or a colon followed by a range of revisions (as in svn:mergeinfo, e.g. “:100-200”). Paths may appear on a line of their own to avoid overlong lines. Any revision numbers mentioned elsewhere in the description are prefixed with the letter ‘r’ (e.g. “r99”).
The description has two parts: One part describes the “incoming change” applied by an update, merge, or switch operation. The other part describes the “local change” which occurred in the working copy or perhaps in the history of a merge target branch. Both parts are provided independently to allow for some flexibility when displaying the description. As a convention, displaying the “incoming change” first and the “local change” second is recommended.
By default, the description is based only on information available in the working copy. If svn_client_conflict_tree_get_details() was already called for @a conflict, the description might also contain useful information obtained from the repository and provide for a much better user experience.
@since New in 1.10.