svn_client_mkdir4

Function svn_client_mkdir4 

pub unsafe extern "C" fn svn_client_mkdir4(
    paths: *const apr_array_header_t,
    make_parents: svn_boolean_t,
    revprop_table: *const apr_hash_t,
    commit_callback: svn_commit_callback2_t,
    commit_baton: *mut c_void,
    ctx: *mut svn_client_ctx_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Create a directory, either in a repository or a working copy.

@a paths is an array of (const char *) paths, either all local WC paths or all URLs.

If @a paths contains URLs, use the authentication baton in @a ctx and @a message to immediately attempt to commit the creation of the directories in @a paths in the repository.

Else, create the directories on disk, and attempt to schedule them for addition (using svn_client_add(), whose docstring you should read).

If @a make_parents is TRUE, create any non-existent parent directories also.

If non-NULL, @a revprop_table is a hash table holding additional, custom revision properties (const char * names mapped to svn_string_t * values) to be set on the new revision in the event that this is a committing operation. This table cannot contain any standard Subversion properties.

@a ctx->log_msg_func3/@a ctx->log_msg_baton3 are a callback/baton combo that this function can use to query for a commit log message when one is needed.

If @a ctx->notify_func2 is non-NULL, when the directory has been created (successfully) in the working copy, call @a ctx->notify_func2 with @a ctx->notify_baton2 and the path of the new directory. Note that this is only called for items added to the working copy.

If @a commit_callback is non-NULL, then for each successful commit, call @a commit_callback with @a commit_baton and a #svn_commit_info_t for the commit.

@since New in 1.7.