pub unsafe extern "C" fn svn_client_move4(
commit_info_p: *mut *mut svn_commit_info_t,
src_path: *const c_char,
dst_path: *const c_char,
force: svn_boolean_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Similar to svn_client_move5(), with only one @a src_path, @a move_as_child set to @c FALSE, @a revprop_table passed as NULL, and @a make_parents set to @c FALSE.
Note: The behaviour of @a force changed in 1.5 (r860885 and r861421), when the ‘move’ semantics were improved to just move the source including any modified and/or unversioned items in it. Before that, @a force controlled what happened to such items, but now @a force is ignored.
@since New in 1.4.
@deprecated Provided for backward compatibility with the 1.4 API.