svn_client_propget3

Function svn_client_propget3 

pub unsafe extern "C" fn svn_client_propget3(
    props: *mut *mut apr_hash_t,
    propname: *const c_char,
    target: *const c_char,
    peg_revision: *const svn_opt_revision_t,
    revision: *const svn_opt_revision_t,
    actual_revnum: *mut svn_revnum_t,
    depth: svn_depth_t,
    changelists: *const apr_array_header_t,
    ctx: *mut svn_client_ctx_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Similar to svn_client_propget4(), but with the following change to the output hash keys: keys are `char *’ paths, prefixed by @a target, which is a working copy path or a URL.

This function returns SVN_ERR_ENTRY_NOT_FOUND where svn_client_propget4 would return SVN_ERR_UNVERSIONED_RESOURCE.

@since New in 1.5. @deprecated Provided for backward compatibility with the 1.6 API.