svn_client_relocate2

Function svn_client_relocate2 

pub unsafe extern "C" fn svn_client_relocate2(
    wcroot_dir: *const c_char,
    from_prefix: *const c_char,
    to_prefix: *const c_char,
    ignore_externals: svn_boolean_t,
    ctx: *mut svn_client_ctx_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Recursively modify a working copy rooted at @a wcroot_dir, changing any repository URLs that begin with @a from_prefix to begin with @a to_prefix instead.

@param wcroot_dir Working copy root directory @param from_prefix Original URL @param to_prefix New URL @param ignore_externals If not set, recurse into external working copies after relocating the primary working copy @param ctx svn_client_ctx_t @param pool The pool from which to perform memory allocations

@since New in 1.7