pub unsafe extern "C" fn svn_client_unlock(
targets: *const apr_array_header_t,
break_lock: svn_boolean_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Unlock @a targets in the repository. @a targets is an array of const char * paths - either all working copy paths or all URLs. All targets must be in the same repository.
If the targets are WC paths, and @a break_lock is FALSE, the working copy must contain a lock for each target. If this is not the case, or the working copy lock doesn’t match the lock token in the repository, an error will be signaled.
If the targets are URLs, the locks may be broken even if @a break_lock is FALSE, but only if the lock owner is the same as the authenticated user.
If @a break_lock is TRUE, the locks will be broken in the repository. In both cases, the locks, if any, will be removed from the working copy if the targets are WC paths.
The notification functions in @a ctx will be called for each target. If the target was successfully unlocked, #svn_wc_notify_unlocked will be used. Else, if the error is directly related to unlocking the path (see #SVN_ERR_IS_UNLOCK_ERROR), #svn_wc_notify_failed_unlock will be used and the error will be passed in the notification structure.
Use @a pool for temporary allocations.
@since New in 1.2.