pub unsafe extern "C" fn svn_cmdline_create_auth_baton2(
ab: *mut *mut svn_auth_baton_t,
non_interactive: svn_boolean_t,
username: *const c_char,
password: *const c_char,
config_dir: *const c_char,
no_auth_cache: svn_boolean_t,
trust_server_cert_unknown_ca: svn_boolean_t,
trust_server_cert_cn_mismatch: svn_boolean_t,
trust_server_cert_expired: svn_boolean_t,
trust_server_cert_not_yet_valid: svn_boolean_t,
trust_server_cert_other_failure: svn_boolean_t,
cfg: *mut svn_config_t,
cancel_func: svn_cancel_func_t,
cancel_baton: *mut c_void,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *ab to an authentication baton allocated from @a pool and initialized with the standard set of authentication providers used by the command line client.
@a non_interactive, @a username, @a password, @a config_dir, and @a no_auth_cache are the values of the command line options of the corresponding names.
If @a non_interactive is @c TRUE, then the following parameters control whether an invalid SSL certificate will be accepted regardless of a specific verification failure:
@a trust_server_cert_unknown_ca: If @c TRUE, accept certificates from unknown certificate authorities.
@a trust_server_cert_cn_mismatch: If @c TRUE, accept certificates even if the Common Name attribute of the certificate differs from the hostname of the server.
@a trust_server_cert_expired: If @c TRUE, accept certificates even if they are expired.
@a trust_server_cert_not_yet_valid: If @c TRUE, accept certificates from the future.
@a trust_server_cert_other_failure: If @c TRUE, accept certificates even if any other verification failure than the above occured.
@a cfg is the @c SVN_CONFIG_CATEGORY_CONFIG configuration, and @a cancel_func and @a cancel_baton control the cancellation of the prompting providers that are initialized.
Use @a pool for all allocations.
@since New in 1.9.