svn_cmdline_setup_auth_baton

Function svn_cmdline_setup_auth_baton 

pub unsafe extern "C" fn svn_cmdline_setup_auth_baton(
    ab: *mut *mut svn_auth_baton_t,
    non_interactive: svn_boolean_t,
    username: *const c_char,
    password: *const c_char,
    config_dir: *const c_char,
    no_auth_cache: svn_boolean_t,
    cfg: *mut svn_config_t,
    cancel_func: svn_cancel_func_t,
    cancel_baton: *mut c_void,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Similar to svn_cmdline_create_auth_baton(), but with @a trust_server_cert always set to false.

@since New in 1.4. @deprecated Provided for backward compatibility with the 1.5 API. Use svn_cmdline_create_auth_baton() instead.

@note This deprecation does not follow the usual pattern of putting a new number on end of the function’s name. Instead, the new function name is distinguished from the old by a grammatical improvement: the verb “create” instead of the noun “setup”.