svn_config_find_group

Function svn_config_find_group 

pub unsafe extern "C" fn svn_config_find_group(
    cfg: *mut svn_config_t,
    key: *const c_char,
    master_section: *const c_char,
    pool: *mut apr_pool_t,
) -> *const c_char
Enumerate the group @a master_section in @a cfg. Each variable value is interpreted as a list of glob patterns (separated by comma and optional whitespace). Return the name of the first variable whose value matches @a key, or @c NULL if no variable matches.