svn_config_get

Function svn_config_get 

pub unsafe extern "C" fn svn_config_get(
    cfg: *mut svn_config_t,
    valuep: *mut *const c_char,
    section: *const c_char,
    option: *const c_char,
    default_value: *const c_char,
)
Find the value of a (@a section, @a option) pair in @a cfg, set @a *valuep to the value.

If @a cfg is @c NULL, just sets @a *valuep to @a default_value. If the value does not exist, expand and return @a default_value. @a default_value can be NULL.

The returned value will be valid at least until the next call to svn_config_get(), or for the lifetime of @a default_value. It is safest to consume the returned value immediately.

This function may change @a cfg by expanding option values.