pub unsafe extern "C" fn svn_config_get_config(
cfg_hash: *mut *mut apr_hash_t,
config_dir: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Read configuration information from the standard sources and merge it into the hash @a *cfg_hash. If @a config_dir is not NULL it specifies a directory from which to read the configuration files, overriding all other sources. Otherwise, first read any system-wide configurations (from a file or from the registry), then merge in personal configurations (again from file or registry). The hash and all its data are allocated in @a pool.
@a *cfg_hash is a hash whose keys are @c const char * configuration categories (@c SVN_CONFIG_CATEGORY_SERVERS, @c SVN_CONFIG_CATEGORY_CONFIG, etc.) and whose values are the @c svn_config_t * items representing the configuration values for that category.