svn_config_read3

Function svn_config_read3 

pub unsafe extern "C" fn svn_config_read3(
    cfgp: *mut *mut svn_config_t,
    file: *const c_char,
    must_exist: svn_boolean_t,
    section_names_case_sensitive: svn_boolean_t,
    option_names_case_sensitive: svn_boolean_t,
    result_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Read configuration data from @a file (a file or registry path) into @a *cfgp, allocated in @a pool.

If @a file does not exist, then if @a must_exist, return an error, otherwise return an empty @c svn_config_t.

If @a section_names_case_sensitive is @c TRUE, populate section name hashes case sensitively, except for the @c “DEFAULT” section.

If @a option_names_case_sensitive is @c TRUE, populate option name hashes case sensitively.

@since New in 1.8.