svn_cstring_match_glob_list

Function svn_cstring_match_glob_list 

pub unsafe extern "C" fn svn_cstring_match_glob_list(
    str_: *const c_char,
    list: *const apr_array_header_t,
) -> svn_boolean_t
Return @c TRUE iff @a str matches any of the elements of @a list, a list of zero or more glob patterns.