svn_diff_file_diff_2

Function svn_diff_file_diff_2 

pub unsafe extern "C" fn svn_diff_file_diff_2(
    diff: *mut *mut svn_diff_t,
    original: *const c_char,
    modified: *const c_char,
    options: *const svn_diff_file_options_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
A convenience function to produce a diff between two files.

@since New in 1.4.

Return a diff object in @a *diff (allocated from @a pool) that represents the difference between an @a original file and @a modified file. (The file arguments must be full paths to the files.)

Compare lines according to the relevant fields of @a options.