svn_diff_hunk_get_original_length

Function svn_diff_hunk_get_original_length 

pub unsafe extern "C" fn svn_diff_hunk_get_original_length(
    hunk: *const svn_diff_hunk_t,
) -> svn_linenum_t
Return the number of lines in the original @a hunk text, as parsed from the hunk header. @since New in 1.7.