svn_diff_hunk_readline_original_text

Function svn_diff_hunk_readline_original_text 

pub unsafe extern "C" fn svn_diff_hunk_readline_original_text(
    hunk: *mut svn_diff_hunk_t,
    stringbuf: *mut *mut svn_stringbuf_t,
    eol: *mut *const c_char,
    eof: *mut svn_boolean_t,
    result_pool: *mut apr_pool_t,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Allocate @a *stringbuf in @a result_pool, and read into it one line of the original text of @a hunk. The line-terminator is detected automatically and stored in @a *eol if @a eol is not NULL. If EOF is reached, set @a *eof to TRUE, and set @a *eol to NULL if the hunk text does not end with a newline character and @a eol is not NULL. Temporary allocations will be performed in @a scratch_pool.

@see svn_diff_hunk_t @since New in 1.7.