pub unsafe extern "C" fn svn_diff_hunk_reset_original_text(
hunk: *mut svn_diff_hunk_t,
)Expand description
Reset the original text of @a hunk so it can be read again from the start. @since New in 1.7.
pub unsafe extern "C" fn svn_diff_hunk_reset_original_text(
hunk: *mut svn_diff_hunk_t,
)Reset the original text of @a hunk so it can be read again from the start. @since New in 1.7.