pub unsafe extern "C" fn svn_dirent_create(
result_pool: *mut apr_pool_t,
) -> *mut svn_dirent_tExpand description
Create a new svn_dirent_t instance with all values initialized to their not-available values.
@since New in 1.8.
pub unsafe extern "C" fn svn_dirent_create(
result_pool: *mut apr_pool_t,
) -> *mut svn_dirent_tCreate a new svn_dirent_t instance with all values initialized to their not-available values.
@since New in 1.8.