svn_dirent_join

Function svn_dirent_join 

pub unsafe extern "C" fn svn_dirent_join(
    base: *const c_char,
    component: *const c_char,
    result_pool: *mut apr_pool_t,
) -> *mut c_char
Join a base dirent (@a base) with a component (@a component).

If either @a base or @a component is the empty string, then the other argument will be copied and returned. If both are the empty string then empty string is returned.

If the @a component is an absolute dirent, then it is copied and returned. The platform specific rules for joining paths are used to join the components.

This function is NOT appropriate for native (local) file dirents. Only for “internal” canonicalized dirents, since it uses ‘/’ for the separator.

Allocate the result in @a result_pool.

@since New in 1.6.