svn_dirent_join_many

Function svn_dirent_join_many 

pub unsafe extern "C" fn svn_dirent_join_many(
    result_pool: *mut apr_pool_t,
    base: *const c_char,
    ...
) -> *mut c_char
Join multiple components onto a @a base dirent. The components are terminated by a @c SVN_VA_NULL.

If any component is the empty string, it will be ignored.

If any component is an absolute dirent, then it resets the base and further components will be appended to it.

See svn_dirent_join() for further notes about joining dirents.

Allocate the result in @a result_pool.

@since New in 1.6.