pub unsafe extern "C" fn svn_dso_load(
dso: *mut *mut apr_dso_handle_t,
libname: *const c_char,
) -> *mut svn_error_tExpand description
Attempt to load @a libname, returning it in @a *dso.
If @a libname cannot be loaded set @a *dso to NULL and return @c SVN_NO_ERROR.
@note Due to pool lifetime issues DSOs are all loaded into a global pool, so you must be certain that there is a bounded number of them that will ever be loaded by the system, otherwise you will leak memory.
@since New in 1.4.