svn_err_best_message

Function svn_err_best_message 

pub unsafe extern "C" fn svn_err_best_message(
    err: *const svn_error_t,
    buf: *mut c_char,
    bufsize: apr_size_t,
) -> *const c_char
If @a err has a custom error message, return that, otherwise store the generic error string associated with @a err->apr_err into @a buf (terminating with NULL) and return @a buf.

@since New in 1.4.

@note @a buf and @a bufsize are provided in the interface so that this function is thread-safe and yet does no allocation.