svn_error_find_cause

Function svn_error_find_cause 

pub unsafe extern "C" fn svn_error_find_cause(
    err: *mut svn_error_t,
    apr_err: apr_status_t,
) -> *mut svn_error_t
Return the first error in @a err’s chain that has an error code @a apr_err or #SVN_NO_ERROR if there is no error with that code. The returned error should @em not be cleared as it shares memory with @a err.

If @a err is #SVN_NO_ERROR, return #SVN_NO_ERROR.

@since New in 1.7.