pub unsafe extern "C" fn svn_error_get_malfunction_handler() -> svn_error_malfunction_handler_tExpand description
Return the malfunction handler that is currently in effect. @since New in 1.9.
pub unsafe extern "C" fn svn_error_get_malfunction_handler() -> svn_error_malfunction_handler_tReturn the malfunction handler that is currently in effect. @since New in 1.9.