svn_error_wrap_apr

Function svn_error_wrap_apr 

pub unsafe extern "C" fn svn_error_wrap_apr(
    status: apr_status_t,
    fmt: *const c_char,
    ...
) -> *mut svn_error_t
Wrap a @a status from an APR function. If @a fmt is NULL, this is equivalent to svn_error_create(status,NULL,NULL). Otherwise, the error message is constructed by formatting @a fmt and the following arguments according to apr_psprintf(), and then appending “: “ and the error message corresponding to @a status. (If UTF-8 translation of the APR error message fails, the “: “ and APR error are not appended to the error message.)