svn_fs_access_add_lock_token2

Function svn_fs_access_add_lock_token2 

pub unsafe extern "C" fn svn_fs_access_add_lock_token2(
    access_ctx: *mut svn_fs_access_t,
    path: *const c_char,
    token: *const c_char,
) -> *mut svn_error_t
Push a lock-token @a token associated with path @a path into the context @a access_ctx. The context remembers all tokens it receives, and makes them available to fs functions. The token and path are not duplicated into @a access_ctx’s pool; make sure the token’s lifetime is at least as long as @a access_ctx.

@since New in 1.6.