pub unsafe extern "C" fn svn_fs_apply_text(
contents_p: *mut *mut svn_stream_t,
root: *mut svn_fs_root_t,
path: *const c_char,
result_checksum: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Write data directly to the file @a path in @a root. @a root must be the root of a transaction, not a revision.
Set @a *contents_p to a stream ready to receive full textual data. When the caller closes this stream, the data replaces the previous contents of the file. The caller must write all file data and close the stream before making further changes to the transaction.
If @a path does not exist in @a root, return an error. (You cannot use this routine to create new files; use svn_fs_make_file() to create an empty file first.)
@a result_checksum is the hex MD5 digest for the final fulltext written to the stream. It is ignored if NULL, but if not null, it must match the checksum of the result; if it does not, then the @a *contents_p call which detects the mismatch will return the error #SVN_ERR_CHECKSUM_MISMATCH.
Do any necessary temporary allocation in @a pool.
@note This is like svn_fs_apply_textdelta(), but takes the text straight.