pub unsafe extern "C" fn svn_fs_apply_textdelta(
contents_p: *mut svn_txdelta_window_handler_t,
contents_baton_p: *mut *mut c_void,
root: *mut svn_fs_root_t,
path: *const c_char,
base_checksum: *const c_char,
result_checksum: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Apply a text delta to the file @a path in @a root. @a root must be the root of a transaction, not a revision.
Set @a *contents_p to a function ready to receive text delta windows describing how to change the file’s contents, relative to its current contents. Set @a *contents_baton_p to a baton to pass to @a *contents_p.
If @a path does not exist in @a root, return an error. (You cannot use this routine to create new files; use svn_fs_make_file() to create an empty file first.)
@a base_checksum is the hex MD5 digest for the base text against which the delta is to be applied; it is ignored if NULL, and may be ignored even if not NULL. If it is not ignored, it must match the checksum of the base text against which svndiff data is being applied; if not, svn_fs_apply_textdelta() or the @a *contents_p call which detects the mismatch will return the error #SVN_ERR_CHECKSUM_MISMATCH (if there is no base text, there may still be an error if @a base_checksum is neither NULL nor the checksum of the empty string).
@a result_checksum is the hex MD5 digest for the fulltext that results from this delta application. It is ignored if NULL, but if not NULL, it must match the checksum of the result; if it does not, then the @a *contents_p call which detects the mismatch will return the error #SVN_ERR_CHECKSUM_MISMATCH.
The caller must send all delta windows including the terminating NULL window to @a *contents_p before making further changes to the transaction.
Do temporary allocation in @a pool.