svn_fs_begin_txn2

Function svn_fs_begin_txn2 

pub unsafe extern "C" fn svn_fs_begin_txn2(
    txn_p: *mut *mut svn_fs_txn_t,
    fs: *mut svn_fs_t,
    rev: svn_revnum_t,
    flags: apr_uint32_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Begin a new transaction on the filesystem @a fs, based on existing revision @a rev. Set @a *txn_p to a pointer to the new transaction. When committed, this transaction will create a new revision.

Allocate the new transaction in @a pool; when @a pool is freed, the new transaction will be closed (neither committed nor aborted).

@a flags determines transaction enforcement behaviors, and is composed from the constants SVN_FS_TXN_* (#SVN_FS_TXN_CHECK_OOD etc.).

@note If you’re building a txn for committing, you probably don’t want to call this directly. Instead, call svn_repos_fs_begin_txn_for_commit(), which honors the repository’s hook configurations.

@since New in 1.2.