svn_fs_freeze

Function svn_fs_freeze 

pub unsafe extern "C" fn svn_fs_freeze(
    fs: *mut svn_fs_t,
    freeze_func: svn_fs_freeze_func_t,
    freeze_baton: *mut c_void,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Take an exclusive lock on @a fs to prevent commits and then invoke @a freeze_func passing @a freeze_baton.

@note @a freeze_func must not, directly or indirectly, call any function that attempts to take out a lock on the underlying repository. These include functions for packing, hotcopying, setting revprops and commits. Attempts to do so may result in a deadlock.

@note The BDB backend doesn’t implement this feature so most callers should not call this function directly but should use the higher level svn_repos_freeze() instead.

@see svn_repos_freeze()

@since New in 1.8.