svn_fs_lock_target_set_token

Function svn_fs_lock_target_set_token 

pub unsafe extern "C" fn svn_fs_lock_target_set_token(
    target: *mut svn_fs_lock_target_t,
    token: *const c_char,
)
Update @a target changing the token to @a token, @a token can be NULL.

The @a token is not duplicated and so must have a lifetime at least as long as @a target.

@since New in 1.9.