pub unsafe extern "C" fn svn_fs_node_created_rev(
revision: *mut svn_revnum_t,
root: *mut svn_fs_root_t,
path: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *revision to the revision in which the node-revision identified by @a path under @a root was created; that is, to the revision in which @a path under @a root was last modified. @a *revision will be set to #SVN_INVALID_REVNUM for uncommitted nodes (i.e. modified nodes under a transaction root). Note that the root of an unmodified transaction is not itself considered to be modified; in that case, return the revision upon which the transaction was based.
Use @a pool for any temporary allocations.