svn_fs_node_prop

Function svn_fs_node_prop 

pub unsafe extern "C" fn svn_fs_node_prop(
    value_p: *mut *mut svn_string_t,
    root: *mut svn_fs_root_t,
    path: *const c_char,
    propname: *const c_char,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set @a *value_p to the value of the property named @a propname of @a path in @a root. If the node has no property by that name, set @a *value_p to zero. Allocate the result in @a pool.