svn_fs_props_different

Function svn_fs_props_different 

pub unsafe extern "C" fn svn_fs_props_different(
    different_p: *mut svn_boolean_t,
    root1: *mut svn_fs_root_t,
    path1: *const c_char,
    root2: *mut svn_fs_root_t,
    path2: *const c_char,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Determine if the properties of two path/root combinations are different.

Set @a *different_p to #TRUE if the properties at @a path1 under @a root1 differ from those at @a path2 under @a root2, or set it to #FALSE if they are the same. Both paths must exist under their respective roots, and both roots must be in the same filesystem. Do any necessary temporary allocation in @a scratch_pool.

@note For the purposes of preserving accurate history, certain bits of code (such as the repository dump code) need to care about the distinction between situations when the properties are “different” and “have changed across two points in history”. We have a pair of functions that can answer both of these questions, svn_fs_props_different() and svn_fs_props_changed(). See issue 4598 for more details.

@see svn_fs_props_changed

@since New in 1.9.