pub unsafe extern "C" fn svn_fs_verify(
path: *const c_char,
fs_config: *mut apr_hash_t,
start: svn_revnum_t,
end: svn_revnum_t,
notify_func: svn_fs_progress_notify_func_t,
notify_baton: *mut c_void,
cancel_func: svn_cancel_func_t,
cancel_baton: *mut c_void,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Perform backend-specific data consistency and correctness validations to the Subversion filesystem (mainly the meta-data) located in the directory @a path. Use the backend-specific configuration @a fs_config when opening the filesystem. @a NULL is valid for all backends. Use @a scratch_pool for temporary allocations.
@a start and @a end define the (minimum) range of revisions to check. If @a start is #SVN_INVALID_REVNUM, it defaults to @c r0. Likewise, @a end will default to the current youngest repository revision when given as #SVN_INVALID_REVNUM. Since meta data checks may have to touch other revisions as well, you may receive notifications for revisions outside the specified range. In fact, it is perfectly legal for a FS implementation to always check all revisions.
Global invariants are only guaranteed to get verified when @a r0 has been included in the range of revisions to check.
The optional @a notify_func callback is only a general feedback that the operation is still in process but may be called in random revisions order and more than once for the same revision, i.e. r2, r1, r2 would be a valid sequence.
The optional @a cancel_func callback will be invoked as usual to allow the user to preempt this potentially lengthy operation.
@note You probably don’t want to use this directly. Take a look at svn_repos_verify_fs2() instead, which does non-backend-specific verifications as well.
@note To ensure a full verification using all tests and covering all revisions, you must call this function and #svn_fs_verify_root.
@note Implementors, please do tests that can be done efficiently for a single revision in #svn_fs_verify_root. This function is meant for global checks or tests that require an expensive context setup.
@see svn_repos_verify_fs2() @see svn_fs_verify_root()
@since New in 1.8.