svn_hash_read2

Function svn_hash_read2 

pub unsafe extern "C" fn svn_hash_read2(
    hash: *mut apr_hash_t,
    stream: *mut svn_stream_t,
    terminator: *const c_char,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Read a hash table from @a stream, storing the resultants names and values in @a hash. Use a @a pool for all allocations. @a hash will have const char * keys and svn_string_t * values. If @a terminator is NULL, expect the hash to be terminated by the end of the stream; otherwise, expect the hash to be terminated by a line containing @a terminator. Pass @c SVN_HASH_TERMINATOR to use the conventional terminator “END”.

@since New in 1.1.