pub unsafe extern "C" fn svn_hash_write_incremental(
hash: *mut apr_hash_t,
oldhash: *mut apr_hash_t,
stream: *mut svn_stream_t,
terminator: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Similar to svn_hash_write2(), but only writes out entries for keys which differ between @a hash and @a oldhash, and also writes out deletion lines for keys which are present in @a oldhash but not in @a hash.
@since New in 1.1.