pub unsafe extern "C" fn svn_io_file_aligned_seek(
file: *mut apr_file_t,
block_size: apr_off_t,
buffer_start: *mut apr_off_t,
offset: apr_off_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set the file pointer of the #APR_BUFFERED @a file to @a offset. In contrast to #svn_io_file_seek, this function will attempt to resize the internal data buffer to @a block_size bytes and to read data aligned to multiples of that value. The beginning of the block will be returned in @a buffer_start, if that is not NULL. Uses @a scratch_pool for temporary allocations.
@note Due to limitations of the APR API, the alignment may not be successful. If you never use any other seek function on @a file, however, you are virtually guaranteed to get at least 4kByte alignment for all reads.
@note Calling this for non-buffered files is legal but inefficient.
@since New in 1.9