pub unsafe extern "C" fn svn_io_open_unique_file3(
file: *mut *mut apr_file_t,
temp_path: *mut *const c_char,
dirpath: *const c_char,
delete_when: svn_io_file_del_t,
result_pool: *mut apr_pool_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Create a writable file, with an arbitrary and unique name, in the directory @a dirpath. Set @a *temp_path to its full path, and set @a *file to the file handle, both allocated from @a result_pool. Either @a file or @a temp_path may be @c NULL. If @a file is @c NULL, the file will be created but not open.
If @a dirpath is @c NULL, use the path returned from svn_io_temp_dir(). (Note that when using the system-provided temp directory, it may not be possible to atomically rename the resulting file due to cross-device issues.)
The file will be deleted according to @a delete_when. If that is #svn_io_file_del_on_pool_cleanup, it refers to @a result_pool. If it is #svn_io_file_del_on_close and @a file is @c NULL, the file will be deleted before this function returns.
When passing @c svn_io_file_del_none please don’t forget to eventually remove the temporary file to avoid filling up the system temp directory. It is often appropriate to bind the lifetime of the temporary file to the lifetime of a pool by using @c svn_io_file_del_on_pool_cleanup.
Temporary allocations will be performed in @a scratch_pool.
@since New in 1.6 @see svn_stream_open_unique()