svn_io_set_file_affected_time

Function svn_io_set_file_affected_time 

pub unsafe extern "C" fn svn_io_set_file_affected_time(
    apr_time: apr_time_t,
    path: *const c_char,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set the timestamp of file @a path to @a apr_time. @a path is utf8-encoded.

@note This is the APR mtime which corresponds to the traditional mtime on Unix, and the last write time on Windows.