pub unsafe extern "C" fn svn_io_set_file_read_only(
path: *const c_char,
ignore_enoent: svn_boolean_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Make a file as read-only as the operating system allows. @a path is the utf8-encoded path to the file. If @a ignore_enoent is @c TRUE, don’t fail if the target file doesn’t exist.
If @a path is a symlink, do nothing.
@note If @a path is a directory, act on it as though it were a file, as described above, but note that you probably don’t want to call this function on directories. We have left it effective on directories for compatibility reasons, but as its name implies, it should be used only for files.