svn_io_set_file_read_write_carefully

Function svn_io_set_file_read_write_carefully 

pub unsafe extern "C" fn svn_io_set_file_read_write_carefully(
    path: *const c_char,
    enable_write: svn_boolean_t,
    ignore_enoent: svn_boolean_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Similar to svn_io_set_file_read_* functions. Change the read-write permissions of a file. @since New in 1.1.

When making @a path read-write on operating systems with unix style permissions, set the permissions on @a path to the permissions that are set when a new file is created (effectively honoring the user’s umask).

When making the file read-only on operating systems with unix style permissions, remove all write permissions.

On other operating systems, toggle the file’s “writability” as much as the operating system allows.

@a path is the utf8-encoded path to the file. If @a enable_write is @c TRUE, then make the file read-write. If @c FALSE, make it read-only. If @a ignore_enoent is @c TRUE, don’t fail if the target file doesn’t exist.

@deprecated Provided for backward compatibility with the 1.3 API.