pub unsafe extern "C" fn svn_iter_apr_array(
completed: *mut svn_boolean_t,
array: *const apr_array_header_t,
func: svn_iter_apr_array_cb_t,
baton: *mut c_void,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Iterate over the elements in @a array calling @a func for each one until there are no more elements or @a func returns an error.
Uses @a pool for temporary allocations.
If @a completed is not NULL, then on return - if @a func returns no errors - @a *completed will be set to @c TRUE.
If @a func returns an error other than @c SVN_ERR_ITER_BREAK, that error is returned. When @a func returns @c SVN_ERR_ITER_BREAK, iteration is interrupted, but no error is returned and @a *completed is set to @c FALSE (even if this iteration was the last one).
@since New in 1.5.