svn_path_check_valid

Function svn_path_check_valid 

pub unsafe extern "C" fn svn_path_check_valid(
    path: *const c_char,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Check whether @a path is a valid Subversion path.

A valid Subversion pathname is a UTF-8 string without control characters. “Valid” means Subversion can store the pathname in a repository. There may be other, OS-specific, limitations on what paths can be represented in a working copy.

ASSUMPTION: @a path is a valid UTF-8 string. This function does not check UTF-8 validity.

Return @c SVN_NO_ERROR if valid and @c SVN_ERR_FS_PATH_SYNTAX if invalid.

@note Despite returning an @c SVN_ERR_FS_* error, this function has nothing to do with the versioned filesystem’s concept of validity.

@since New in 1.2.