pub unsafe extern "C" fn svn_path_component_count(
path: *const c_char,
) -> apr_size_tExpand description
Return the number of components in the canonicalized @a path.
@since New in 1.1.
pub unsafe extern "C" fn svn_path_component_count(
path: *const c_char,
) -> apr_size_tReturn the number of components in the canonicalized @a path.
@since New in 1.1.