pub unsafe extern "C" fn svn_path_decompose(
path: *const c_char,
pool: *mut apr_pool_t,
) -> *mut apr_array_header_tExpand description
Decompose the canonicalized @a path into an array of const char * components, allocated in @a pool. If @a path is absolute, the first component will be a lone dir separator (the root directory).