pub unsafe extern "C" fn svn_path_get_longest_ancestor(
path1: *const c_char,
path2: *const c_char,
pool: *mut apr_pool_t,
) -> *mut c_charExpand description
Return the longest common path shared by two canonicalized paths, @a path1 and @a path2. If there’s no common ancestor, return the empty path.
@a path1 and @a path2 may be URLs. In order for two URLs to have a common ancestor, they must (a) have the same protocol (since two URLs with the same path but different protocols may point at completely different resources), and (b) share a common ancestor in their path component, i.e. ‘protocol://’ is not a sufficient ancestor.
@deprecated Provided for backward compatibility with the 1.6 API. New code should use svn_dirent_get_longest_ancestor(), svn_uri_get_longest_ancestor(), svn_relpath_get_longest_ancestor() or svn_fspath__get_longest_ancestor().