svn_path_join_many

Function svn_path_join_many 

pub unsafe extern "C" fn svn_path_join_many(
    pool: *mut apr_pool_t,
    base: *const c_char,
    ...
) -> *mut c_char
Join multiple components onto a @a base path, allocated in @a pool. The components are terminated by a @c SVN_VA_NULL.

If any component is the empty string, it will be ignored.

If any component is an absolute path, then it resets the base and further components will be appended to it.

This function does not support URLs.

See svn_path_join() for further notes about joining paths.

@deprecated Provided for backward compatibility with the 1.6 API. For new code, consider using svn_dirent_join_many() or a sequence of calls to one of the *_join() functions.