pub unsafe extern "C" fn svn_path_remove_component(
path: *mut svn_stringbuf_t,
)Expand description
Remove one component off the end of the canonicalized @a path.
pub unsafe extern "C" fn svn_path_remove_component(
path: *mut svn_stringbuf_t,
)Remove one component off the end of the canonicalized @a path.