svn_path_split_if_file

Function svn_path_split_if_file 

pub unsafe extern "C" fn svn_path_split_if_file(
    path: *const c_char,
    pdirectory: *mut *const c_char,
    pfile: *mut *const c_char,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Return the path part of the canonicalized @a path in @a *pdirectory, and the file part in @a *pfile. If @a path is a directory, set @a *pdirectory to @a path, and @a *pfile to the empty string. If @a path does not exist it is treated as if it is a file, since directories do not normally vanish.

@deprecated Provided for backward compatibility with the 1.6 API. New code should implement the required logic directly; no direct replacement is provided.