pub unsafe extern "C" fn svn_prop_needs_translation(
prop_name: *const c_char,
) -> svn_boolean_tExpand description
If @a prop_name requires that its value be stored as UTF8/LF in the repository, then return @c TRUE. Else return @c FALSE. This is for users of libsvn_client or libsvn_fs, since it their responsibility to do this translation in both directions. (See svn_subst_translate_string()/svn_subst_detranslate_string() for help with this task.)