pub unsafe extern "C" fn svn_ra_do_status2(
session: *mut svn_ra_session_t,
reporter: *mut *const svn_ra_reporter3_t,
report_baton: *mut *mut c_void,
status_target: *const c_char,
revision: svn_revnum_t,
depth: svn_depth_t,
status_editor: *const svn_delta_editor_t,
status_baton: *mut c_void,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Ask the RA layer to describe the status of a working copy with respect to @a revision of the repository (or HEAD, if @a revision is invalid).
The client initially provides a @a status_editor/@a status_baton to the RA layer; this editor contains knowledge of where the change will begin in the working copy (when open_root() is called).
In return, the client receives a @a reporter/@a report_baton. The client then describes its working copy by making calls into the @a reporter.
When finished, the client calls @a reporter->finish_report(). The RA layer then does a complete drive of @a status_editor, ending with close_edit(), to report, essentially, what would be modified in the working copy were the client to call do_update(). @a status_target is an optional single path component will restrict the scope of the status report to an entry in the directory represented by the @a session’s URL, or empty if the entire directory is meant to be examined.
Get status as deeply as @a depth indicates. If @a depth is #svn_depth_unknown, get the status down to the ambient depth of the working copy. If @a depth is deeper than the working copy, include changes that would be needed to populate the working copy to that depth.
The caller may not perform any RA operations using @a session before finishing the report, and may not perform any RA operations using @a session from within the editing operations of @a status_editor.
Use @a pool for memory allocation.
@note The reporter provided by this function does NOT supply copy- from information to the diff editor callbacks.
@note In order to prevent pre-1.5 servers from doing more work than needed, and sending too much data back, a pre-1.5 ‘recurse’ directive may be sent to the server, based on @a depth.
@since New in 1.5.