svn_ra_get_locks2

Function svn_ra_get_locks2 

pub unsafe extern "C" fn svn_ra_get_locks2(
    session: *mut svn_ra_session_t,
    locks: *mut *mut apr_hash_t,
    path: *const c_char,
    depth: svn_depth_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set @a *locks to a hashtable which represents all locks on or below @a path.

@a depth limits the returned locks to those associated with paths within the specified depth of @a path, and must be one of the following values: #svn_depth_empty, #svn_depth_files, #svn_depth_immediates, or #svn_depth_infinity.

The hashtable maps (const char *) absolute fs paths to (const svn_lock_t *) structures. The hashtable – and all keys and values – are allocated in @a pool.

@note It is not considered an error for @a path to not exist in HEAD. Such a search will simply return no locks.

@note This functionality is not available in pre-1.2 servers. If the server doesn’t implement it, an @c SVN_ERR_RA_NOT_IMPLEMENTED error is returned.

@since New in 1.7.