svn_ra_reparent

Function svn_ra_reparent 

pub unsafe extern "C" fn svn_ra_reparent(
    ra_session: *mut svn_ra_session_t,
    url: *const c_char,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Change the root URL of an open @a ra_session to point to a new path in the same repository. @a url is the new root URL. Use @a pool for temporary allocations.

If @a url has a different repository root than the current session URL, return @c SVN_ERR_RA_ILLEGAL_URL.

@since New in 1.4.