svn_rangelist_diff

Function svn_rangelist_diff 

pub unsafe extern "C" fn svn_rangelist_diff(
    deleted: *mut *mut svn_rangelist_t,
    added: *mut *mut svn_rangelist_t,
    from: *const svn_rangelist_t,
    to: *const svn_rangelist_t,
    consider_inheritance: svn_boolean_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Calculate the delta between two rangelists consisting of @c svn_merge_range_t * elements (sorted in ascending order), @a from and @a to, and place the result in @a *deleted and @a *added (neither output argument will ever be @c NULL).

@a consider_inheritance determines how to account for the inheritability of the two rangelist’s ranges when calculating the diff, as described for svn_mergeinfo_diff().

@since New in 1.5.