svn_rangelist_remove

Function svn_rangelist_remove 

pub unsafe extern "C" fn svn_rangelist_remove(
    output: *mut *mut svn_rangelist_t,
    eraser: *const svn_rangelist_t,
    whiteboard: *const svn_rangelist_t,
    consider_inheritance: svn_boolean_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Removes @a eraser (the subtrahend) from @a whiteboard (the minuend), and places the resulting difference in @a output.

Note: @a eraser and @a whiteboard must be sorted as said by @c svn_sort_compare_ranges(). @a output is guaranteed to be in sorted order.

@a consider_inheritance determines how to account for the @c svn_merge_range_t inheritable field when comparing @a whiteboard’s and @a *eraser’s rangelists for equality. @see svn_mergeinfo_diff().

Allocate the entire output in @a pool.

@since New in 1.5.