svn_relpath_canonicalize_safe

Function svn_relpath_canonicalize_safe 

pub unsafe extern "C" fn svn_relpath_canonicalize_safe(
    canonical_relpath: *mut *const c_char,
    non_canonical_result: *mut *const c_char,
    relpath: *const c_char,
    result_pool: *mut apr_pool_t,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Return a new @a *canonical_relpath like @a relpath, but transformed such that some types of relpath specification redundancies are removed.

Similar to svn_relpath_canonicalize() (which see), but returns an error if the @a relpath can not be canonicalized or of the result does not pass the svn_relpath_is_canonical() test.

If the function fails and @a non_canonical_result is not @c NULL, the result of the failed canonicalization attempt (which may be @c NULL) will be returned in @a *non_canonical_result.

Allocates the results in @a result_pool. Uses @a scratch_pool for temporary allocations.

@since New in 1.12.