pub unsafe extern "C" fn svn_repos_fs_change_node_prop(
root: *mut svn_fs_root_t,
path: *const c_char,
name: *const c_char,
value: *const svn_string_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Validating wrapper for svn_fs_change_node_prop() (which see for argument descriptions).
If @a name’s kind is not #svn_prop_regular_kind, return #SVN_ERR_REPOS_BAD_ARGS. If @a name is an “svn:” property, validate its @a value and return SVN_ERR_BAD_PROPERTY_VALUE if it is invalid for the property.
@note Originally, the only properties validated were the “svn:” properties #SVN_PROP_REVISION_LOG and #SVN_PROP_REVISION_DATE. For the current validation rules see the private function svn_repos__validate_prop().