svn_repos_trace_node_locations

Function svn_repos_trace_node_locations 

pub unsafe extern "C" fn svn_repos_trace_node_locations(
    fs: *mut svn_fs_t,
    locations: *mut *mut apr_hash_t,
    fs_path: *const c_char,
    peg_revision: svn_revnum_t,
    location_revisions: *const apr_array_header_t,
    authz_read_func: svn_repos_authz_func_t,
    authz_read_baton: *mut c_void,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set @a *locations to be a mapping of the revisions to the paths of the file @a fs_path present at the repository in revision @a peg_revision, where the revisions are taken out of the array @a location_revisions.

@a location_revisions is an array of svn_revnum_t’s and @a *locations maps ‘svn_revnum_t *’ to ‘const char *’.

If optional @a authz_read_func is non-NULL, then use it (and @a authz_read_baton) to verify that the peg-object is readable. If not, return SVN_ERR_AUTHZ_UNREADABLE. Also use the @a authz_read_func to check that every path returned in the hash is readable. If an unreadable path is encountered, stop tracing and return SVN_NO_ERROR.

@a pool is used for all allocations.

@since New in 1.1.