svn_subst_create_specialfile

Function svn_subst_create_specialfile 

pub unsafe extern "C" fn svn_subst_create_specialfile(
    stream: *mut *mut svn_stream_t,
    path: *const c_char,
    result_pool: *mut apr_pool_t,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set @a *stream to a writable stream that accepts content in the “normal form” for a special file, to be located at @a path, and will create that file when the stream is closed. The stream will be allocated in @a result_pool, and any temporary allocations will be made in @a scratch_pool.

If the platform does not support the semantics of the special file, write a regular file containing the “normal form” text. This enables special files to be written and read on platforms that do not treat them as special.

Note: the target file is created in a temporary location, then renamed into position, so the creation can be considered “atomic”.

@since New in 1.6.