svn_subst_detranslate_string

Function svn_subst_detranslate_string 

pub unsafe extern "C" fn svn_subst_detranslate_string(
    new_value: *mut *mut svn_string_t,
    value: *const svn_string_t,
    for_output: svn_boolean_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Translate the string @a value from UTF8 and LF line-endings into native character encoding and native line-endings. If @a for_output is TRUE, translate to the character encoding of the output locale, else to that of the default locale.

Set @a *new_value to the translated string, allocated in @a pool.