svn_subst_eol_style_from_value

Function svn_subst_eol_style_from_value 

pub unsafe extern "C" fn svn_subst_eol_style_from_value(
    style: *mut svn_subst_eol_style_t,
    eol: *mut *const c_char,
    value: *const c_char,
)
Set @a *style to the appropriate @c svn_subst_eol_style_t and @a *eol to the appropriate cstring for a given svn:eol-style property value.

Set @a *eol to

  • @c NULL for @c svn_subst_eol_style_none, or

  • a NULL-terminated C string containing the native eol marker for this platform, for @c svn_subst_eol_style_native, or

  • a NULL-terminated C string containing the eol marker indicated by the property value, for @c svn_subst_eol_style_fixed.

If @a *style is NULL, it is ignored.