pub unsafe extern "C" fn svn_subst_keywords_differ2(
a: *mut apr_hash_t,
b: *mut apr_hash_t,
compare_values: svn_boolean_t,
pool: *mut apr_pool_t,
) -> svn_boolean_tExpand description
Return @c TRUE if @a a and @a b do not hold the same keywords.
@a a and @a b are hashes of the form produced by svn_subst_build_keywords2().
@since New in 1.3.
If @a compare_values is @c TRUE, “same” means that the @a a and @a b contain exactly the same set of keywords, and the values of corresponding keywords match as well. Else if @a compare_values is @c FALSE, then “same” merely means that @a a and @a b hold the same set of keywords, although those keywords’ values might differ.
@a a and/or @a b may be @c NULL; for purposes of comparison, @c NULL is equivalent to holding no keywords.