pub unsafe extern "C" fn svn_subst_stream_detranslated(
stream_p: *mut *mut svn_stream_t,
src: *const c_char,
eol_style: svn_subst_eol_style_t,
eol_str: *const c_char,
always_repair_eols: svn_boolean_t,
keywords: *mut apr_hash_t,
special: svn_boolean_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *stream_p to a stream that detranslates the file @a src from working copy form to normal form, allocated in @a pool.
The values specified for @a eol_style, @a *eol_str, @a keywords and @a special, should be the ones used to translate the file to its working copy form. Usually, these are the values specified by the user in the files’ properties.
Inconsistent line endings in the file will be automatically repaired (made consistent) for some eol styles. For all others, an error is returned. By setting @a always_repair_eols to @c TRUE, eols will be made consistent even for those styles which don’t have it by default.
@since New in 1.4.
@deprecated Provided for backward compatibility with the 1.5 API. Use svn_subst_stream_from_specialfile if the source is special; otherwise, use svn_subst_stream_translated_to_normal_form.