pub unsafe extern "C" fn svn_subst_translation_required(
style: svn_subst_eol_style_t,
eol: *const c_char,
keywords: *mut apr_hash_t,
special: svn_boolean_t,
force_eol_check: svn_boolean_t,
) -> svn_boolean_tExpand description
Indicates whether the working copy and normalized versions of a file with the given the parameters differ. If @a force_eol_check is TRUE, the routine also accounts for all translations required due to repairing fixed eol styles.
@since New in 1.4