svn_uri_basename

Function svn_uri_basename 

pub unsafe extern "C" fn svn_uri_basename(
    uri: *const c_char,
    result_pool: *mut apr_pool_t,
) -> *const c_char
Get the (URI-decoded) basename of the specified canonicalized @a uri. The basename is defined as the last component of the uri. If the @a uri is root, return “”. The returned value will have no slashes in it.

Example: svn_uri_basename(“http://server/foo/bar”) -> “bar”

Allocate the result in @a result_pool.

@since New in 1.7.