pub unsafe extern "C" fn svn_utf_initialize(pool: *mut apr_pool_t)Expand description
Like svn_utf_initialize2() but without the ability to force the native encoding to UTF-8.
@deprecated Provided for backward compatibility with the 1.7 API.
pub unsafe extern "C" fn svn_utf_initialize(pool: *mut apr_pool_t)Like svn_utf_initialize2() but without the ability to force the native encoding to UTF-8.
@deprecated Provided for backward compatibility with the 1.7 API.