pub unsafe extern "C" fn svn_utf_initialize2(
assume_native_utf8: svn_boolean_t,
pool: *mut apr_pool_t,
)Expand description
Initialize the UTF-8 encoding/decoding routines. Allocate cached translation handles in a subpool of @a pool.
If @a assume_native_utf8 is TRUE, the native character set is assumed to be UTF-8, i.e. conversion is a no-op. This is useful in contexts where the native character set is ASCII but UTF-8 should be used regardless (e.g. for mod_dav_svn which runs within httpd and always uses the āCā locale).
@note It is optional to call this function, but if it is used, no other svn function may be in use in other threads during the call of this function or when @a pool is cleared or destroyed. Initializing the UTF-8 routines will improve performance.
@since New in 1.8.