pub unsafe extern "C" fn svn_ver_check_list2(
my_version: *const svn_version_t,
checklist: *const svn_version_checklist_t,
comparator: Option<unsafe extern "C" fn(arg1: *const svn_version_t, arg2: *const svn_version_t) -> svn_boolean_t>,
) -> *mut svn_error_tExpand description
Perform a series of version compatibility checks. Checks if @a my_version is compatible with each entry in @a checklist. @a checklist must end with an entry whose label is @c NULL.
@a my_version is considered to be compatible with a version in @a checklist if @a comparator returns #TRUE when called with @a my_version as the first parammeter and the @a checklist version as the second parameter.
@see svn_ver_compatible(), svn_ver_equal()
@note Subversion’s own code invariably uses svn_ver_equal() as @a comparator, since the cmdline tools sometimes use non-public APIs (such as utility functions that haven’t been promoted to svn_cmdline.h). Third-party code SHOULD use svn_ver_compatible() as @a comparator.
@since New in 1.9.