svn_ver_compatible

Function svn_ver_compatible 

pub unsafe extern "C" fn svn_ver_compatible(
    my_version: *const svn_version_t,
    lib_version: *const svn_version_t,
) -> svn_boolean_t
Check library version compatibility. Return #TRUE if the client’s version, given in @a my_version, is compatible with the library version, provided in @a lib_version.

This function checks for version compatibility as per our guarantees, but requires an exact match when linking to an unreleased library. A development client is always compatible with a previous released library.

@note Implements the #svn_ver_check_list2.@a comparator interface.

@since New in 1.1.