svn_wc_read_kind2

Function svn_wc_read_kind2 

pub unsafe extern "C" fn svn_wc_read_kind2(
    kind: *mut svn_node_kind_t,
    wc_ctx: *mut svn_wc_context_t,
    local_abspath: *const c_char,
    show_deleted: svn_boolean_t,
    show_hidden: svn_boolean_t,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set @a kind to the #svn_node_kind_t of @a abspath. Use @a wc_ctx to access the working copy, and @a scratch_pool for all temporary allocations.

If @a abspath is not under version control, set @a kind to #svn_node_none.

If @a show_hidden and @a show_deleted are both @c FALSE, the kind of scheduled for delete, administrative only ‘not present’ and excluded nodes is reported as #svn_node_none. This is recommended as a check for ‘is there a versioned file or directory here?’

If @a show_deleted is FALSE, but @a show_hidden is @c TRUE then only scheduled for delete and administrative only ‘not present’ nodes are reported as #svn_node_none. This is recommended as check for ‘Can I add a node here?’

If @a show_deleted is TRUE, but @a show_hidden is FALSE, then only administrative only ‘not present’ nodes and excluded nodes are reported as #svn_node_none. This behavior is the behavior bescribed as ‘hidden’ before Subversion 1.7.

If @a show_hidden and @a show_deleted are both @c TRUE all nodes are reported.

@since New in 1.8.