svn_x509_parse_cert

Function svn_x509_parse_cert 

pub unsafe extern "C" fn svn_x509_parse_cert(
    certinfo: *mut *mut svn_x509_certinfo_t,
    buf: *const c_char,
    buflen: apr_size_t,
    result_pool: *mut apr_pool_t,
    scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_t
Parse x509 @a der certificate data from @a buf with length @a buflen and return certificate information in @a *certinfo, allocated in @a result_pool.

@note This function has been written with the intent of display data in a certificate for a user to see. As a result, it does not do much validation on the data it parses from the certificate. It does not for instance verify that the certificate is signed by the issuer. It does not verify a trust chain. It does not error on critical extensions it does not know how to parse. So while it can be used as part of a certificate validation scheme, it can’t be used alone for that purpose.

@since New in 1.9.