#[repr(C)]pub struct svn_client_proplist_item_t {
pub node_name: *mut svn_stringbuf_t,
pub prop_hash: *mut apr_hash_t,
}Expand description
This is a structure which stores a filename and a hash of property names and values.
@deprecated Provided for backward compatibility with the 1.4 API.
Fields
node_name: *mut svn_stringbuf_tThe name of the node on which these properties are set.
prop_hash: *mut apr_hash_tA hash of (const char *) property names, and (svn_string_t *) property values.