#[repr(C)]pub struct svn_opt_subcommand_desc3_t__bindgen_ty_1 {
pub optch: c_int,
pub desc: *const c_char,
}Expand description
A list of option help descriptions, keyed by the option unique enum (the 2nd field in apr_getopt_option_t), which override the generic descriptions given in an apr_getopt_option_t on a per-subcommand basis.
Fields
optch: c_intdesc: *const c_charTrait Implementations
Sourceimpl Clone for svn_opt_subcommand_desc3_t__bindgen_ty_1
impl Clone for svn_opt_subcommand_desc3_t__bindgen_ty_1
Sourcefn clone(&self) -> svn_opt_subcommand_desc3_t__bindgen_ty_1
fn clone(&self) -> svn_opt_subcommand_desc3_t__bindgen_ty_1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for svn_opt_subcommand_desc3_t__bindgen_ty_1