pub unsafe extern "C" fn svn_base64_encode2(
output: *mut svn_stream_t,
break_lines: svn_boolean_t,
pool: *mut apr_pool_t,
) -> *mut svn_stream_tExpand description
Return a writable generic stream which will encode binary data in base64 format and write the encoded data to @a output. If @a break_lines is true, newlines will be inserted periodically; otherwise the output stream will only consist of base64 encoding characters. Be sure to close the stream when done writing in order to squeeze out the last bit of encoded data. The stream is allocated in @a pool.
@since New in 1.10.