pub unsafe extern "C" fn svn_client_checkout3(
result_rev: *mut svn_revnum_t,
URL: *const c_char,
path: *const c_char,
peg_revision: *const svn_opt_revision_t,
revision: *const svn_opt_revision_t,
depth: svn_depth_t,
ignore_externals: svn_boolean_t,
allow_unver_obstructions: svn_boolean_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Checkout a working copy from a repository.
@param[out] result_rev If non-NULL, the value of the revision checked
out from the repository.
@param[in] URL The repository URL of the checkout source.
@param[in] path The root of the new working copy.
@param[in] peg_revision The peg revision.
@param[in] revision The operative revision.
@param[in] depth The depth of the operation. If #svn_depth_unknown,
then behave as if for #svn_depth_infinity, except in the case
of resuming a previous checkout of @a path (i.e., updating),
in which case use the depth of the existing working copy.
@param[in] ignore_externals If @c TRUE, don’t process externals
definitions as part of this operation.
@param[in] allow_unver_obstructions If @c TRUE, then tolerate existing
unversioned items that obstruct incoming paths. Only
obstructions of the same type (file or dir) as the added
item are tolerated. The text of obstructing files is left
as-is, effectively treating it as a user modification after
the checkout. Working properties of obstructing items are
set equal to the base properties.
If @c FALSE, then abort if there are any unversioned
obstructing items.
@param[in] ctx The standard client context, used for authentication and
notification.
@param[in] pool Used for any temporary allocation.
@return A pointer to an #svn_error_t of the type (this list is not
exhaustive):
#SVN_ERR_UNSUPPORTED_FEATURE if @a URL refers to a file rather
than a directory;
#SVN_ERR_RA_ILLEGAL_URL if @a URL does not exist;
#SVN_ERR_CLIENT_BAD_REVISION if @a revision is not one of
#svn_opt_revision_number, #svn_opt_revision_head, or
#svn_opt_revision_date.
If no error occurred, return #SVN_NO_ERROR.
@since New in 1.5.
@see #svn_depth_t
#svn_client_ctx_t
@ref clnt_revisions for
a discussion of operative and peg revisions.