pub unsafe extern "C" fn svn_client_log2(
targets: *const apr_array_header_t,
start: *const svn_opt_revision_t,
end: *const svn_opt_revision_t,
limit: c_int,
discover_changed_paths: svn_boolean_t,
strict_node_history: svn_boolean_t,
receiver: svn_log_message_receiver_t,
receiver_baton: *mut c_void,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Similar to svn_client_log3(), but with the @c kind field of @a peg_revision set to #svn_opt_revision_unspecified.
@par Important: A special case for the revision range HEAD:1, which was present in svn_client_log(), has been removed from svn_client_log2(). Instead, it is expected that callers will specify the range HEAD:0, to avoid a #SVN_ERR_FS_NO_SUCH_REVISION error when invoked against an empty repository (i.e. one not containing a revision 1).
@deprecated Provided for compatibility with the 1.3 API. @since New in 1.2.