pub unsafe extern "C" fn svn_client_log5(
targets: *const apr_array_header_t,
peg_revision: *const svn_opt_revision_t,
revision_ranges: *const apr_array_header_t,
limit: c_int,
discover_changed_paths: svn_boolean_t,
strict_node_history: svn_boolean_t,
include_merged_revisions: svn_boolean_t,
revprops: *const apr_array_header_t,
receiver: svn_log_entry_receiver_t,
receiver_baton: *mut c_void,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Invoke @a receiver with @a receiver_baton on each log message from each (#svn_opt_revision_range_t *) range in @a revision_ranges in turn, inclusive (but never invoke @a receiver on a given log message more than once).
@a targets contains either a URL followed by zero or more relative paths, or 1 working copy path, as const char *, for which log messages are desired. @a receiver is invoked only on messages whose revisions involved a change to some path in @a targets. @a peg_revision indicates in which revision @a targets are valid. If @a peg_revision is #svn_opt_revision_unspecified, it defaults to #svn_opt_revision_head for URLs or #svn_opt_revision_working for WC paths.
If @a limit is greater than zero only invoke @a receiver on the first @a limit logs.
If @a discover_changed_paths is set, then the @c changed_paths and @c changed_paths2 fields in the @c log_entry argument to @a receiver will be populated on each invocation. @note The @c text_modified and @c props_modified fields of the changed paths structure may have the value #svn_tristate_unknown if the repository does not report that information.
If @a strict_node_history is set, copy history (if any exists) will not be traversed while harvesting revision logs for each target.
If @a include_merged_revisions is set, log information for revisions which have been merged to @a targets will also be returned.
If @a revprops is NULL, retrieve all revision properties; else, retrieve only the revision properties named by the (const char *) array elements (i.e. retrieve none if the array is empty).
Use @a pool for any temporary allocation.
If @a ctx->notify_func2 is non-NULL, then call @a ctx->notify_func2/baton2 with a ‘skip’ signal on any unversioned targets.
@since New in 1.6.