pub unsafe extern "C" fn svn_client_proplist2(
props: *mut *mut apr_array_header_t,
target: *const c_char,
peg_revision: *const svn_opt_revision_t,
revision: *const svn_opt_revision_t,
recurse: svn_boolean_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Similar to svn_client_proplist3(), except the properties are returned as an array of #svn_client_proplist_item_t * structures instead of by invoking the receiver function, there’s no support for @a changelists filtering, and @a recurse is used instead of a #svn_depth_t parameter (FALSE corresponds to #svn_depth_empty, and TRUE to #svn_depth_infinity).
@since New in 1.2.
@deprecated Provided for backward compatibility with the 1.4 API.