pub unsafe extern "C" fn svn_client_propset_local(
propname: *const c_char,
propval: *const svn_string_t,
targets: *const apr_array_header_t,
depth: svn_depth_t,
skip_checks: svn_boolean_t,
changelists: *const apr_array_header_t,
ctx: *mut svn_client_ctx_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a propname to @a propval on each (const char *) target in @a targets. The targets must be all working copy paths. A @a propval of @c NULL will delete the property.
If @a depth is #svn_depth_empty, set the property on each member of @a targets only; if #svn_depth_files, set it on @a targets and their file children (if any); if #svn_depth_immediates, on @a targets and all of their immediate children (both files and directories); if #svn_depth_infinity, on @a targets and everything beneath them.
@a changelists is an array of const char * changelist names, used as a restrictive filter on items whose properties are set; that is, don’t set properties on any item unless it’s a member of one of those changelists. If @a changelists is empty (or altogether @c NULL), no changelist filtering occurs.
If @a propname is an svn-controlled property (i.e. prefixed with #SVN_PROP_PREFIX), then the caller is responsible for ensuring that the value is UTF8-encoded and uses LF line-endings.
If @a skip_checks is TRUE, do no validity checking. But if @a skip_checks is FALSE, and @a propname is not a valid property for @a targets, return an error, either #SVN_ERR_ILLEGAL_TARGET (if the property is not appropriate for @a targets), or #SVN_ERR_BAD_MIME_TYPE (if @a propname is “svn:mime-type”, but @a propval is not a valid mime-type).
If @a ctx->cancel_func is non-NULL, invoke it passing @a ctx->cancel_baton at various places during the operation.
Use @a scratch_pool for all memory allocation.
@since New in 1.7.