pub unsafe extern "C" fn svn_client_propset_remote(
propname: *const c_char,
propval: *const svn_string_t,
url: *const c_char,
skip_checks: svn_boolean_t,
base_revision_for_url: svn_revnum_t,
revprop_table: *const apr_hash_t,
commit_callback: svn_commit_callback2_t,
commit_baton: *mut c_void,
ctx: *mut svn_client_ctx_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a propname to @a propval on @a url. A @a propval of @c NULL will delete the property.
Immediately attempt to commit the property change in the repository, using the authentication baton in @a ctx and @a ctx->log_msg_func3/@a ctx->log_msg_baton3.
If the property has changed on @a url since revision @a base_revision_for_url (which must not be #SVN_INVALID_REVNUM), no change will be made and an error will be returned.
If non-NULL, @a revprop_table is a hash table holding additional, custom revision properties (const char * names mapped to svn_string_t * values) to be set on the new revision. This table cannot contain any standard Subversion properties.
If @a commit_callback is non-NULL, then call @a commit_callback with @a commit_baton and a #svn_commit_info_t for the commit.
If @a propname is an svn-controlled property (i.e. prefixed with #SVN_PROP_PREFIX), then the caller is responsible for ensuring that the value is UTF8-encoded and uses LF line-endings.
If @a skip_checks is TRUE, do no validity checking. But if @a skip_checks is FALSE, and @a propname is not a valid property for @a url, return an error, either #SVN_ERR_ILLEGAL_TARGET (if the property is not appropriate for @a url), or * #SVN_ERR_BAD_MIME_TYPE (if @a propname is “svn:mime-type”, but @a propval is not a valid mime-type).
Use @a scratch_pool for all memory allocation.
@since New in 1.7.