pub unsafe extern "C" fn svn_client_relocate(
dir: *const c_char,
from_prefix: *const c_char,
to_prefix: *const c_char,
recurse: svn_boolean_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Similar to svn_client_relocate2(), but with @a ignore_externals always TRUE.
@note As of the 1.7 API, @a dir is required to be a working copy root directory, and @a recurse is required to be TRUE.
@deprecated Provided for limited backwards compatibility with the 1.6 API.