pub unsafe extern "C" fn svn_client_remove_from_changelists(
paths: *const apr_array_header_t,
depth: svn_depth_t,
changelists: *const apr_array_header_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Remove each path in @a paths (recursing to @a depth as necessary) from changelists to which they are currently assigned.
@a paths is an array of (const char *) local WC paths.
@a changelists is an array of const char * changelist names, used as a restrictive filter on items whose changelist assignments are removed; that is, don’t remove from a changeset any item unless it’s currently a member of one of those changelists. If @a changelists is empty (or altogether @c NULL), all changelist assignments in and under each path in @a paths (to @a depth) will be removed.
@note This metadata is purely a client-side “bookkeeping” convenience, and is entirely managed by the working copy.
@since New in 1.5.