svn_client_revprop_get

Function svn_client_revprop_get 

pub unsafe extern "C" fn svn_client_revprop_get(
    propname: *const c_char,
    propval: *mut *mut svn_string_t,
    URL: *const c_char,
    revision: *const svn_opt_revision_t,
    set_rev: *mut svn_revnum_t,
    ctx: *mut svn_client_ctx_t,
    pool: *mut apr_pool_t,
) -> *mut svn_error_t
Set @a *propval to the value of @a propname on revision @a revision in the repository represented by @a URL. Use the authentication baton in @a ctx for authentication, and @a pool for all memory allocation. Return the actual rev queried in @a *set_rev.

If @a propname does not exist on @a revision, set @a *propval to @c NULL.

Note that unlike its cousin svn_client_propget(), this routine doesn’t affect the working copy at all; it’s a pure network operation that queries an unversioned property attached to a revision. This can query log messages, dates, authors, and the like.