pub unsafe extern "C" fn svn_client_revprop_list(
props: *mut *mut apr_hash_t,
URL: *const c_char,
revision: *const svn_opt_revision_t,
set_rev: *mut svn_revnum_t,
ctx: *mut svn_client_ctx_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *props to a hash of the revision props attached to @a revision in the repository represented by @a URL. Use the authentication baton cached in @a ctx for authentication, and @a pool for all memory allocation. Return the actual rev queried in @a *set_rev.
The allocated hash maps (const char *) property names to (#svn_string_t *) property values.
Note that unlike its cousin svn_client_proplist(), this routine doesn’t read a working copy at all; it’s a pure network operation that reads unversioned properties attached to a revision.