pub unsafe extern "C" fn svn_cmdline_output_encoding(
pool: *mut apr_pool_t,
) -> *const c_charExpand description
Return the name of the output encoding allocated in @a pool, or @c APR_LOCALE_CHARSET if the output encoding is the same as the locale encoding.
@since New in 1.3.