pub unsafe extern "C" fn svn_config_read_auth_data(
hash: *mut *mut apr_hash_t,
cred_kind: *const c_char,
realmstring: *const c_char,
config_dir: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Use @a cred_kind and @a realmstring to locate a file within the ~/.subversion/auth/ area. If the file exists, initialize @a *hash and load the file contents into the hash, using @a pool. If the file doesn’t exist, set @a *hash to NULL.
If @a config_dir is not NULL it specifies a directory from which to read the config overriding all other sources.
Besides containing the original credential fields, the hash will also contain @c SVN_CONFIG_REALMSTRING_KEY. The caller can examine this value as a sanity-check that the correct file was loaded.
The hashtable will contain const char * keys and svn_string_t * values.