pub unsafe extern "C" fn svn_config_walk_auth_data(
config_dir: *const c_char,
walk_func: svn_config_auth_walk_func_t,
walk_baton: *mut c_void,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Call @a walk_func with @a walk_baton and information describing each credential cached within the Subversion auth store located under @a config_dir. If the callback sets its delete_cred return flag, delete the associated credential.
If @a config_dir is not NULL, it must point to an alternative config directory location. If it is NULL, the default location is used.
@note @a config_dir may only be NULL in 1.8.2 and later.
@note Removing credentials from the config-based disk store will not purge them from any open svn_auth_baton_t instance. Consider using svn_auth_forget_credentials() – from the @a walk_func, even – for this purpose.
@note Removing credentials from the config-based disk store will not also remove any related credentials from third-party password stores. (Implementations of @a walk_func which delete credentials may wish to consult the “passtype” element of @a hash, if any, to see if a third-party store – such as “gnome-keyring” or “kwallet” is being used to hold the most sensitive portion of the credentials for this @a cred_kind and @a realmstring.)
@see svn_auth_forget_credentials()
@since New in 1.8.