pub unsafe extern "C" fn svn_dirent_basename(
dirent: *const c_char,
result_pool: *mut apr_pool_t,
) -> *const c_charExpand description
Gets the name of the specified canonicalized @a dirent as it is known within its parent directory. If the @a dirent is root, return “”. The returned value will not have slashes in it.
Example: svn_dirent_basename(“/foo/bar”) -> “bar”
If @a result_pool is NULL, return a pointer to the basename in @a dirent, otherwise allocate the result in @a result_pool.
@note If an empty string is passed, then an empty string will be returned.
@since New in 1.7.