pub unsafe extern "C" fn svn_dirent_is_root(
dirent: *const c_char,
len: apr_size_t,
) -> svn_boolean_tExpand description
Return TRUE if @a dirent is considered a root directory on the platform at hand. E.g.: On Posix: ‘/’ On Windows: ‘/’, ‘X:/’, ‘//server/share’, ‘X:’
Note that on Windows ‘/’ and ‘X:’ are roots, but paths starting with this root are not absolute.
@since New in 1.5.