pub unsafe extern "C" fn svn_fs_change_node_prop(
root: *mut svn_fs_root_t,
path: *const c_char,
name: *const c_char,
value: *const svn_string_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Change a node’s property’s value, or add/delete a property.
- @a root and @a path indicate the node whose property should change. @a root must be the root of a transaction, not the root of a revision.
- @a name is the name of the property to change.
- @a value is the new value of the property, or zero if the property should be removed altogether. Do any necessary temporary allocation in @a pool.