pub unsafe extern "C" fn svn_fs_hotcopy3(
src_path: *const c_char,
dest_path: *const c_char,
clean: svn_boolean_t,
incremental: svn_boolean_t,
notify_func: svn_fs_hotcopy_notify_t,
notify_baton: *mut c_void,
cancel_func: svn_cancel_func_t,
cancel_baton: *mut c_void,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Copy a possibly live Subversion filesystem from @a src_path to @a dest_path. If @a clean is @c TRUE, perform cleanup on the source filesystem as part of the copy operation; currently, this means deleting copied, unused logfiles for a Berkeley DB source filesystem.
If @a incremental is TRUE, make an effort to avoid re-copying information already present in the destination where possible. If incremental hotcopy is not implemented, raise #SVN_ERR_UNSUPPORTED_FEATURE.
For each revision range copied, @a notify_func will be called with staring and ending revision numbers (both inclusive and not necessarily different) and with the @a notify_baton. Currently, this notification is not triggered by the BDB backend. @a notify_func may be @c NULL if this notification is not required.
The optional @a cancel_func callback will be invoked with @a cancel_baton as usual to allow the user to preempt this potentially lengthy operation.
Use @a scratch_pool for temporary allocations.
@since New in 1.9.