pub unsafe extern "C" fn svn_fs_node_origin_rev(
revision: *mut svn_revnum_t,
root: *mut svn_fs_root_t,
path: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *revision to the revision in which the line of history represented by @a path under @a root originated. Use @a pool for any temporary allocations. If @a root is a transaction root, @a *revision will be set to #SVN_INVALID_REVNUM for any nodes newly added in that transaction (brand new files or directories created using #svn_fs_make_dir or #svn_fs_make_file).
@since New in 1.5.