pub unsafe extern "C" fn svn_fs_txn_root_name(
root: *mut svn_fs_root_t,
pool: *mut apr_pool_t,
) -> *const c_charExpand description
If @a root is the root of a transaction, return the name of the transaction, allocated in @a pool; otherwise, return NULL.