pub unsafe extern "C" fn svn_hash_read(
hash: *mut apr_hash_t,
srcfile: *mut apr_file_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
This function behaves like svn_hash_read2(), but it only works on an apr_file_t input, empty files are accepted, and the hash is expected to be terminated with a line containing “END” or “PROPS-END”.
@deprecated Provided for backward compatibility with the 1.0 API.