pub unsafe extern "C" fn svn_opt_resolve_revisions(
peg_rev: *mut svn_opt_revision_t,
op_rev: *mut svn_opt_revision_t,
is_url: svn_boolean_t,
notice_local_mods: svn_boolean_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Resolve peg revisions and operational revisions in the following way:
-
If @a is_url is set and @a peg_rev->kind is @c svn_opt_revision_unspecified, @a peg_rev->kind defaults to @c svn_opt_revision_head.
-
If @a is_url is not set, and @a peg_rev->kind is @c svn_opt_revision_unspecified, @a peg_rev->kind defaults to @c svn_opt_revision_base.
-
If @a op_rev->kind is @c svn_opt_revision_unspecified, @a op_rev defaults to @a peg_rev.
Both @a peg_rev and @a op_rev may be modified as a result of this function. @a is_url should be set if the path the revisions refer to is a url, and unset otherwise.
If @a notice_local_mods is set, @c svn_opt_revision_working is used, instead of @c svn_opt_revision_base.
Use @a pool for allocations.
@since New in 1.5.