pub unsafe extern "C" fn svn_path_add_component(
path: *mut svn_stringbuf_t,
component: *const c_char,
)Expand description
Add a @a component (a NULL-terminated C-string) to the canonicalized @a path. @a component is allowed to contain directory separators.
If @a path is non-empty, append the appropriate directory separator character, and then @a component. If @a path is empty, simply set it to @a component; don’t add any separator character.
If the result ends in a separator character, then remove the separator.