pub unsafe extern "C" fn svn_path_basename(
path: *const c_char,
pool: *mut apr_pool_t,
) -> *mut c_charExpand description
Get the basename of the specified canonicalized @a path. The basename is defined as the last component of the path (ignoring any trailing slashes). If the @a path is root (“/”), then that is returned. Otherwise, the returned value will have no slashes in it.
Example: svn_path_basename(“/foo/bar”) -> “bar”
The returned basename will be allocated in @a pool.
@note If an empty string is passed, then an empty string will be returned.
@deprecated Provided for backward compatibility with the 1.6 API. New code should use svn_dirent_basename(), svn_uri_basename(), svn_relpath_basename() or svn_fspath__basename().