svn_path_canonicalize

Function svn_path_canonicalize 

pub unsafe extern "C" fn svn_path_canonicalize(
    path: *const c_char,
    pool: *mut apr_pool_t,
) -> *const c_char
Return a new path (or URL) like @a path, but transformed such that some types of path specification redundancies are removed.

This involves collapsing redundant “/./” elements, removing multiple adjacent separator characters, removing trailing separator characters, and possibly other semantically inoperative transformations.

Convert the scheme and hostname to lowercase (see issue #2475)

The returned path may be statically allocated, equal to @a path, or allocated from @a pool.

@deprecated Provided for backward compatibility with the 1.6 API. New code should use svn_dirent_canonicalize(), svn_uri_canonicalize(), svn_relpath_canonicalize() or svn_fspath__canonicalize().