pub unsafe extern "C" fn svn_path_compare_paths(
path1: *const c_char,
path2: *const c_char,
) -> c_intExpand description
Return an integer greater than, equal to, or less than 0, according as @a path1 is greater than, equal to, or less than @a path2.
This function works like strcmp() except that it orders children in subdirectories directly after their parents. This allows using the given ordering for a depth first walk.