pub unsafe extern "C" fn svn_path_get_absolute(
pabsolute: *mut *const c_char,
relative: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Convert @a relative canonicalized path to an absolute path and return the results in @a *pabsolute, allocated in @a pool.
@a relative may be a URL, in which case no attempt is made to convert it, and a copy of the URL is returned.
@deprecated Provided for backward compatibility with the 1.6 API. New code should use svn_dirent_get_absolute() on a non-URL input.