pub unsafe extern "C" fn svn_path_is_empty(
path: *const c_char,
) -> c_intExpand description
Return non-zero iff @a path is empty (“”) or represents the current directory – that is, if prepending it as a component to an existing path would result in no meaningful change.