pub unsafe extern "C" fn svn_path_splitext(
path_root: *mut *const c_char,
path_ext: *mut *const c_char,
path: *const c_char,
pool: *mut apr_pool_t,
)Expand description
Split @a path into a root portion and an extension such that the root + the extension = the original path, and where the extension contains no period (.) characters. If not @c NULL, set @a *path_root to the root portion. If not @c NULL, set @a *path_ext to the extension (or “” if there is no extension found). Allocate both @a *path_root and @a *path_ext in @a pool.
@since New in 1.5.