pub unsafe extern "C" fn svn_property_kind(
prefix_len: *mut c_int,
prop_name: *const c_char,
) -> svn_prop_kind_tExpand description
Return the prop kind of a property named @a prop_name, and (if @a prefix_len is non-@c NULL) set @a *prefix_len to the length of the prefix of @a prop_name that was sufficient to distinguish its kind.
@deprecated Provided for backward compatibility with the 1.7 API.