pub unsafe extern "C" fn svn_ra_do_switch3(
session: *mut svn_ra_session_t,
reporter: *mut *const svn_ra_reporter3_t,
report_baton: *mut *mut c_void,
revision_to_switch_to: svn_revnum_t,
switch_target: *const c_char,
depth: svn_depth_t,
switch_url: *const c_char,
send_copyfrom_args: svn_boolean_t,
ignore_ancestry: svn_boolean_t,
switch_editor: *const svn_delta_editor_t,
switch_baton: *mut c_void,
result_pool: *mut apr_pool_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Ask the RA layer to switch a working copy to a new revision and URL.
This is similar to svn_ra_do_update3(), but also changes the URL of every node in the target tree to a child of the @a switch_url. In contrast, update changes only the revision numbers, leaving any switched subtrees still switched.
@note Pre Subversion 1.8 svnserve based servers always ignore ancestry and never send copyfrom data.
@since New in 1.8.