pub unsafe extern "C" fn svn_ra_get_file(
session: *mut svn_ra_session_t,
path: *const c_char,
revision: svn_revnum_t,
stream: *mut svn_stream_t,
fetched_rev: *mut svn_revnum_t,
props: *mut *mut apr_hash_t,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Fetch the contents and properties of file @a path at @a revision. @a revision may be SVN_INVALID_REVNUM, indicating that the HEAD revision should be used. Interpret @a path relative to the URL in @a session. Use @a pool for all allocations.
If @a revision is @c SVN_INVALID_REVNUM and @a fetched_rev is not @c NULL, then set @a *fetched_rev to the actual revision that was retrieved.
If @a stream is non @c NULL, push the contents of the file at @a stream, do not call svn_stream_close() when finished.
If @a props is non @c NULL, set @a *props to contain the properties of the file. This means @em all properties: not just ones controlled by the user and stored in the repository fs, but non-tweakable ones generated by the SCM system itself (e.g. ‘wcprops’, ‘entryprops’, etc.) The keys are const char *, values are @c svn_string_t *.
The stream handlers for @a stream may not perform any RA operations using @a session.
@since New in 1.2.