pub unsafe extern "C" fn svn_ra_list(
session: *mut svn_ra_session_t,
path: *const c_char,
revision: svn_revnum_t,
patterns: *const apr_array_header_t,
depth: svn_depth_t,
dirent_fields: apr_uint32_t,
receiver: svn_ra_dirent_receiver_t,
receiver_baton: *mut c_void,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Efficiently list everything within a sub-tree. Specify a glob pattern to search for specific files and folders.
In @a session, walk the sub-tree starting at @a path at @a revision down to the given @a depth. For each directory entry found, @a receiver will be called with @a receiver_baton. The starting @a path will be reported as well. Because retrieving elements of a #svn_dirent_t can be expensive, you need to select them individually via flags set in @a dirent_fields.
@a patterns is an optional array of const char *. If it is not @c NULL, only those directory entries will be reported whose last path segment matches at least one of these patterns. This feature uses apr_fnmatch() for glob matching and requiring ‘.’ to matched by dots in the path.
@a path must point to a directory and @a depth must be at least #svn_depth_empty.
If the server doesn’t support the ‘list’ command, return #SVN_ERR_UNSUPPORTED_FEATURE in preference to any other error that might otherwise be returned.
Use @a scratch_pool for temporary memory allocation.
@since New in 1.10.