pub unsafe extern "C" fn svn_ra_unlock(
session: *mut svn_ra_session_t,
path_tokens: *mut apr_hash_t,
break_lock: svn_boolean_t,
lock_func: svn_ra_lock_callback_t,
lock_baton: *mut c_void,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Remove the repository lock for each path in @a path_tokens. @a path_tokens is a hash whose keys are the paths to be locked, and whose values are the corresponding lock tokens for each path. If the path has no corresponding lock token, or if @a break_lock is TRUE, then the corresponding value shall be “”.
Note that unlocking is never anonymous, so any server implementing this function will have to “pull” a username from the client, if it hasn’t done so already.
If @a token points to a lock, but the RA username doesn’t match the lock’s owner, call @a lock_func/@a lock_baton with an error. If @a break_lock is TRUE, however, instead allow the lock to be “broken” by the RA user.
After successfully unlocking a path, @a lock_func is called with the @a lock_baton.
Use @a pool for temporary allocations.
@since New in 1.2.