pub unsafe extern "C" fn svn_repos_node_location_segments(
repos: *mut svn_repos_t,
path: *const c_char,
peg_revision: svn_revnum_t,
start_rev: svn_revnum_t,
end_rev: svn_revnum_t,
receiver: svn_location_segment_receiver_t,
receiver_baton: *mut c_void,
authz_read_func: svn_repos_authz_func_t,
authz_read_baton: *mut c_void,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Call @a receiver and @a receiver_baton to report successive location segments in revisions between @a start_rev and @a end_rev (inclusive) for the line of history identified by the peg-object @a path in @a peg_revision (and in @a repos).
@a end_rev may be #SVN_INVALID_REVNUM to indicate that you want to trace the history of the object to its origin.
@a start_rev may be #SVN_INVALID_REVNUM to indicate “the HEAD revision”. Otherwise, @a start_rev must be younger than @a end_rev (unless @a end_rev is #SVN_INVALID_REVNUM).
@a peg_revision may be #SVN_INVALID_REVNUM to indicate “the HEAD revision”, and must evaluate to be at least as young as @a start_rev.
If optional @a authz_read_func is not @c NULL, then use it (and @a authz_read_baton) to verify that the peg-object is readable. If not, return #SVN_ERR_AUTHZ_UNREADABLE. Also use the @a authz_read_func to check that every path reported in a location segment is readable. If an unreadable path is encountered, report a final (possibly truncated) location segment (if any), stop tracing history, and return #SVN_NO_ERROR.
@a pool is used for all allocations.
@since New in 1.5.