pub unsafe extern "C" fn svn_subst_read_specialfile(
stream: *mut *mut svn_stream_t,
path: *const c_char,
result_pool: *mut apr_pool_t,
scratch_pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *stream to a readable stream containing the “normal form” of the special file located at @a path. The stream will be allocated in @a result_pool, and any temporary allocations will be made in @a scratch_pool.
If the file at @a path is in fact a regular file, just read its content, which should be in the “normal form” for a special file. This enables special files to be written and read on platforms that do not treat them as special.
@since New in 1.6.