pub unsafe extern "C" fn svn_subst_stream_from_specialfile(
stream: *mut *mut svn_stream_t,
path: *const c_char,
pool: *mut apr_pool_t,
) -> *mut svn_error_tExpand description
Set @a *stream to a stream which translates the special file at @a path to the internal representation for special files when read from. When written to, it does the reverse: creating a special file when the stream is closed.
@since New in 1.5.
@deprecated Provided for backward compatibility with the 1.5 API. Callers should use svn_subst_read_specialfile or svn_subst_create_specialfile as appropriate.