pub unsafe extern "C" fn svn_subst_translate_stream(
src_stream: *mut svn_stream_t,
dst_stream: *mut svn_stream_t,
eol_str: *const c_char,
repair: svn_boolean_t,
keywords: *const svn_subst_keywords_t,
expand: svn_boolean_t,
) -> *mut svn_error_tExpand description
Same as svn_subst_translate_stream2(), but does not take a @a pool argument, instead creates a temporary subpool of the global pool, and destroys it before returning.
@deprecated Provided for backward compatibility with the 1.1 API.