#[repr(C)]pub struct svn_cache_config_t {
pub cache_size: apr_uint64_t,
pub file_handle_count: apr_size_t,
pub single_threaded: svn_boolean_t,
}Expand description
Cache resource settings. It controls what caches, in what size and how they will be created. The settings apply for the whole process.
@note Do not extend this data structure as this would break binary compatibility.
@since New in 1.7.
Fields
cache_size: apr_uint64_ttotal cache size in bytes. Please note that this is only soft limit to the total application memory usage and will be exceeded due to temporary objects and other program state. May be 0, resulting in default caching code being used.
file_handle_count: apr_size_tmaximum number of files kept open
single_threaded: svn_boolean_tis this application guaranteed to be single-threaded?