pub type svn_opt_revision_kind = c_uint;Expand description
Various ways of specifying revisions.
@note
In contexts where local mods are relevant, the working' kind refers to the uncommitted "working" revision, which may be modified with respect to its base revision. In other contexts, working’
should behave the same as committed' or current’.